pub fn check_program(program: &HirProgram) -> Result<CheckedProgram, CheckError>Expand description
Check a HIR program and produce semantic annotations for later stages.
pub fn check_program(program: &HirProgram) -> Result<CheckedProgram, CheckError>Check a HIR program and produce semantic annotations for later stages.