Struct CheckedProgram

pub struct CheckedProgram {
    pub signatures: BTreeMap<String, FunctionSig>,
    pub extern_function_names: BTreeSet<String>,
    pub(crate) expr_types: Vec<Ty>,
    pub(crate) call_signatures: Vec<Option<FunctionSig>>,
    pub(crate) local_symbols: Vec<LocalSymbol>,
    pub(crate) local_symbol_occurrences: Vec<LocalSymbolOccurrence>,
    pub(crate) expr_local_symbols: Vec<Option<usize>>,
}
Fully checked program annotations used by later compiler stages.

Fields

signatures: BTreeMap<String, FunctionSig>

Checked signatures keyed by function name.

extern_function_names: BTreeSet<String>

Names of extern functions declared in the program.

expr_types: Vec<Ty>call_signatures: Vec<Option<FunctionSig>>local_symbols: Vec<LocalSymbol>local_symbol_occurrences: Vec<LocalSymbolOccurrence>expr_local_symbols: Vec<Option<usize>>

Implementations

Source

impl CheckedProgram

pub fn expr_ty(&self, expr_id: ExprId) -> &Ty

Return the semantic type assigned to an expression.

pub fn call_signature(&self, expr_id: ExprId) -> Option<&FunctionSig>

Return the resolved call signature for a call expression, if any.

pub fn local_symbols(&self) -> &[LocalSymbol]

Return all local symbols discovered during checking.

pub fn local_symbol_occurrences(&self) -> &[LocalSymbolOccurrence]

Return semantic local-symbol occurrences in deterministic source order.

pub fn expr_local_symbol(&self, expr_id: ExprId) -> Option<usize>

Return the local symbol id resolved for one identifier expression, if any.