pub enum MetaEvalError {
Show 14 variants
UnknownBinding {
name: String,
},
RuntimeBindingUnavailable {
name: String,
},
KnownNameNotMetaValue {
name: String,
kind: &'static str,
},
UnknownMetaFunction {
name: String,
},
DuplicateMetaFunction {
name: String,
},
ArityMismatch {
name: String,
expected: usize,
actual: usize,
},
SpliceExpectedCode {
found: &'static str,
},
MatchExpectedCode,
ExpectedTupleCode {
builtin: &'static str,
},
ExpectedTupleType {
builtin: &'static str,
},
NoMatchArm,
MissingReturnValue {
name: String,
},
TypeMismatch {
expected: String,
actual: String,
},
Elab {
message: String,
},
}Expand description
Meta-evaluation error produced while expanding meta code.
Variants
UnknownBinding
Meta binding lookup failed.
Runtime binding was referenced from a context where it is unavailable.
KnownNameNotMetaValue
Known symbol resolved to an item that is not a meta value.
UnknownMetaFunction
Called meta function name could not be resolved.
DuplicateMetaFunction
Meta function was declared multiple times.
ArityMismatch
Meta function call used wrong number of arguments.
Fields
SpliceExpectedCode
Quote splice expected code but received another value kind.
MatchExpectedCode
Meta match subject was not a code value.
ExpectedTupleCode
Tuple-code builtin received a non-tuple code value.
ExpectedTupleType
Tuple-type builtin received a non-tuple type value.
NoMatchArm
Meta match expression had no matching arm.
MissingReturnValue
Meta function finished without producing a return value.
TypeMismatch
Meta value did not match the expected meta type.
Elab
Elaborating generated runtime expression failed.