Enum MetaEvalError

pub enum MetaEvalError {
Show 14 variants UnknownBinding { name: String, }, RuntimeBindingUnavailable { name: String, }, KnownNameNotMetaValue { name: String, kind: &'static str, }, UnknownMetaFunction { name: String, }, DuplicateMetaFunction { name: String, }, ArityMismatch { name: String, expected: usize, actual: usize, }, SpliceExpectedCode { found: &'static str, }, MatchExpectedCode, ExpectedTupleCode { builtin: &'static str, }, ExpectedTupleType { builtin: &'static str, }, NoMatchArm, MissingReturnValue { name: String, }, TypeMismatch { expected: String, actual: String, }, Elab { message: String, },
}
Meta-evaluation error produced while expanding meta code.

Variants



UnknownBinding

Meta binding lookup failed.

Fields

name: String

Binding name that failed to resolve.



RuntimeBindingUnavailable

Runtime binding was referenced from a context where it is unavailable.

Fields

name: String

Runtime binding name.



KnownNameNotMetaValue

Known symbol resolved to an item that is not a meta value.

Fields

name: String

Symbol name.

kind: &'static str

Symbol category.



UnknownMetaFunction

Called meta function name could not be resolved.

Fields

name: String

Meta function name.



DuplicateMetaFunction

Meta function was declared multiple times.

Fields

name: String

Meta function name.



ArityMismatch

Meta function call used wrong number of arguments.

Fields

name: String

Meta function name.

expected: usize

Expected argument count.

actual: usize

Actual argument count.



SpliceExpectedCode

Quote splice expected code but received another value kind.

Fields

found: &'static str

Actual meta value kind name.



MatchExpectedCode

Meta match subject was not a code value.



ExpectedTupleCode

Tuple-code builtin received a non-tuple code value.

Fields

builtin: &'static str

Builtin function name.



ExpectedTupleType

Tuple-type builtin received a non-tuple type value.

Fields

builtin: &'static str

Builtin function name.



NoMatchArm

Meta match expression had no matching arm.



MissingReturnValue

Meta function finished without producing a return value.

Fields

name: String

Meta function name.



TypeMismatch

Meta value did not match the expected meta type.

Fields

expected: String

Expected meta type rendering.

actual: String

Actual meta type rendering.



Elab

Elaborating generated runtime expression failed.

Fields

message: String

Elaborator error message.