pub enum MirHeapOwnership {
None,
Owned,
OwnedShallow,
BorrowedView,
}Expand description
Heap ownership policy carried by one MIR local.
Variants
None
Local does not participate in runtime heap retain/release operations.
Owned
Local owns one runtime heap allocation that must be released.
OwnedShallow
Local owns one runtime container whose nested payload is borrowed/shared.
BorrowedView
Local denotes a borrowed slice view and must not run retain/release.
Implementations
Sourceimpl MirHeapOwnership
impl MirHeapOwnership
Sourcepub fn uses_heap_ops(self) -> bool
pub fn uses_heap_ops(self) -> bool
Return whether this ownership class requires runtime retain/release operations.