pub struct MirAggregateArg {
pub mode: MirArgMode,
pub local: MirLocalId,
}Expand description
Single aggregate construction argument with explicit ownership mode.
Fields
mode: MirArgModeOwnership mode applied to the argument.
local: MirLocalIdLocal id supplying the argument value.
Implementations
Sourceimpl MirAggregateArg
impl MirAggregateArg
Sourcepub fn is_owned_move(&self) -> bool
pub fn is_owned_move(&self) -> bool
Return whether the aggregate argument mode is owned move.
Sourcepub fn is_owned_copy(&self) -> bool
pub fn is_owned_copy(&self) -> bool
Return whether the aggregate argument mode is owned copy.