pub struct MirFuncId(u32);Expand description
Function identifier in MIR program storage.
Tuple Fields
0: u32Implementations
Sourceimpl MirFuncId
impl MirFuncId
Sourcepub fn as_bits(self) -> u32
pub fn as_bits(self) -> u32
Return the raw bit encoding for this instance.
Warning: the raw bit encoding is opaque and has no
guaranteed correspondence to the entity’s index. It encodes the
entire state of this index value: either a valid index or an
invalid-index sentinel. The value returned by this method should
only be passed to from_bits.
Sourcepub fn from_bits(x: u32) -> MirFuncId
pub fn from_bits(x: u32) -> MirFuncId
Create a new instance from the raw bit encoding.
Warning: the raw bit encoding is opaque and has no
guaranteed correspondence to the entity’s index. It encodes the
entire state of this index value: either a valid index or an
invalid-index sentinel. The value returned by this method should
only be given bits from as_bits.