Struct PassContext

pub struct PassContext {
    pass_ids: PrimaryMap<PassId, &'static str>,
    pass_timings: Vec<PassTiming>,
    provenance: ProvenanceTables,
}
Shared context passed through compiler passes.

Fields

pass_ids: PrimaryMap<PassId, &'static str>pass_timings: Vec<PassTiming>provenance: ProvenanceTables

Implementations

Source

impl PassContext

pub fn new() -> Self

Construct an empty pass context.

pub fn run_timed<T, E, F>( &mut self, pass_name: &'static str, run: F, ) -> Result<T, E>
where F: FnOnce(&mut PassContext, PassId) -> Result<T, E>,

Run one pass, measure its wall-clock duration, and store timing stats.

pub fn run_pass<P>( &mut self, pass: &mut P, input: P::In, ) -> Result<P::Out, P::Error>
where P: Pass,

Run one typed pass, measure duration, and store timing stats.

pub fn run_pass_with_id<P>( &mut self, pass: &mut P, input: P::In, ) -> Result<(PassId, P::Out), P::Error>
where P: Pass,

Run one typed pass and return its pass id with output.

pub fn run_timed_value<T, F>(&mut self, pass_name: &'static str, run: F) -> T
where F: FnOnce(&mut PassContext, PassId) -> T,

Run one infallible pass, measure duration, and store timing stats.

pub fn pass_timings(&self) -> &[PassTiming]

Return recorded pass timings in execution order.

pub fn extend_pass_timings<I>(&mut self, timings: I)
where I: IntoIterator<Item = PassTiming>,

Append externally collected pass timing samples.

pub fn provenance(&self) -> &ProvenanceTables

Return shared provenance tables.

pub fn provenance_mut(&mut self) -> &mut ProvenanceTables

Return mutable shared provenance tables.