pub fn analyze_program(program: &Program) -> StagedSemanticInfoExpand description
Analyze a parsed frontend program and collect reusable pre-expansion metadata.
pub fn analyze_program(program: &Program) -> StagedSemanticInfoAnalyze a parsed frontend program and collect reusable pre-expansion metadata.