Struct MetaExprId
pub struct MetaExprId(u32);Expand description
Stable frontend meta expression identifier.
Tuple Fields
0: u32Implementations
impl MetaExprId
impl MetaExprId
pub fn from_u32(x: u32) -> MetaExprId
pub fn from_u32(x: u32) -> MetaExprId
Create a new instance from a u32.
pub fn as_bits(self) -> u32
pub fn as_bits(self) -> u32
Return the raw bit encoding for this instance.
Warning: the raw bit encoding is opaque and has no
guaranteed correspondence to the entity’s index. It encodes the
entire state of this index value: either a valid index or an
invalid-index sentinel. The value returned by this method should
only be passed to from_bits.
pub fn from_bits(x: u32) -> MetaExprId
pub fn from_bits(x: u32) -> MetaExprId
Create a new instance from the raw bit encoding.
Warning: the raw bit encoding is opaque and has no
guaranteed correspondence to the entity’s index. It encodes the
entire state of this index value: either a valid index or an
invalid-index sentinel. The value returned by this method should
only be given bits from as_bits.