pub fn parse_program(input: &str) -> Result<Program, SyntaxError>Expand description
Parse a source string into a frontend program AST.
pub fn parse_program(input: &str) -> Result<Program, SyntaxError>Parse a source string into a frontend program AST.