pub(super) struct ElaborateProgramPass<'a> {
pub(super) program: &'a Program,
pub(super) subpass_timings: Vec<PassTiming>,
}Expand description
Elaborate runtime-facing AST types and template specializations.
This pass delegates into elab and aggregates internal elaboration
subpass timings so they can be surfaced by the top-level driver.
Input: expanded frontend Program.
Output: elaborated frontend Program.
Pass name: elab.elaborate_program.
Fields
program: &'a ProgramExpanded program to elaborate.
subpass_timings: Vec<PassTiming>Elaboration subpass timings recorded during run.
Implementations
Sourceimpl<'a> ElaborateProgramPass<'a>
impl<'a> ElaborateProgramPass<'a>
Sourcepub(super) fn take_subpass_timings(&mut self) -> Vec<PassTiming>
pub(super) fn take_subpass_timings(&mut self) -> Vec<PassTiming>
Drain recorded elaboration subpass timings after one run.