pub struct ProvenanceTables {
spans: PrimaryMap<SpanId, SourceSpan>,
origins: PrimaryMap<OriginId, Origin>,
}Expand description
Arena-backed provenance tables shared by all passes.
Fields
spans: PrimaryMap<SpanId, SourceSpan>origins: PrimaryMap<OriginId, Origin>Implementations
Sourceimpl ProvenanceTables
impl ProvenanceTables
Sourcepub fn intern_span(&mut self, span: SourceSpan) -> SpanId
pub fn intern_span(&mut self, span: SourceSpan) -> SpanId
Intern a source span and return its stable id.
Sourcepub fn record_parsed(&mut self, span: SourceSpan) -> OriginId
pub fn record_parsed(&mut self, span: SourceSpan) -> OriginId
Record one parsed origin from a source span.
Sourcepub fn record_expanded(&mut self, from: OriginId, phase: PassId) -> OriginId
pub fn record_expanded(&mut self, from: OriginId, phase: PassId) -> OriginId
Record one expanded origin from an existing origin id.
Sourcepub fn record_lowered(&mut self, from: OriginId, phase: PassId) -> OriginId
pub fn record_lowered(&mut self, from: OriginId, phase: PassId) -> OriginId
Record one lowered origin from an existing origin id.
Sourcepub fn record_synthesized(
&mut self,
reason: &'static str,
parent: Option<OriginId>,
) -> OriginId
pub fn record_synthesized( &mut self, reason: &'static str, parent: Option<OriginId>, ) -> OriginId
Record one synthesized origin.
Sourcepub fn span(&self, span_id: SpanId) -> &SourceSpan
pub fn span(&self, span_id: SpanId) -> &SourceSpan
Return one span by id.
Sourcepub fn summary(&self) -> ProvenanceSummary
pub fn summary(&self) -> ProvenanceSummary
Return aggregate counters for provenance tables.